@@ -156,12 +156,12 @@ class GoogleCodeWikiPage(object):
 class GoogleCodeWikiExtractor(GoogleCodeProjectExtractor):
     PAGE_MAP = GoogleCodeProjectExtractor.PAGE_MAP
     PAGE_MAP.update({
-        'wiki_index': GoogleCodeProjectExtractor.BASE_URL + '/p/%s/w/list',
+        'wiki_index': GoogleCodeProjectExtractor.BASE_URL + '/p/{project_name}/w/list',
         })
 
     def get_wiki_pages(self):
         page = self.get_page('wiki_index')
-        RE_WIKI_PAGE_URL = r'^/p/{0}/wiki/.*$'.format(self.gc_project_name)
+        RE_WIKI_PAGE_URL = r'^/p/{0}/wiki/.*$'.format(self.project_name)
         seen = set()
         for a in page.find(id="resultstable").findAll("a"):
             if re.match(RE_WIKI_PAGE_URL, a['href']) and a['href'] not in seen:
@@ -188,7 +188,7 @@ class GoogleCodeWikiImporter(ToolImporter):
         """ Import a Google Code wiki into a new ForgeWiki app.
 
         """
-        extractor = GoogleCodeWikiExtractor(project, project_name)
+        extractor = GoogleCodeWikiExtractor(project_name)
         default_wiki_page_name = extractor.get_default_wiki_page_name()
         with no_notifications(project):
             app = project.install_app(
